"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ldapController = void 0;
const express_1 = __importDefault(require("express"));
const LdapManager_ee_1 = require("../LdapManager.ee");
const helpers_1 = require("../helpers");
const lodash_pick_1 = __importDefault(require("lodash.pick"));
const constants_1 = require("../constants");
const InternalHooks_1 = require("../../InternalHooks");
const typedi_1 = require("typedi");
exports.ldapController = express_1.default.Router();
exports.ldapController.get('/config', async (req, res) => {
    const data = await (0, helpers_1.getLdapConfig)();
    return res.status(200).json({ data });
});
exports.ldapController.post('/test-connection', async (req, res) => {
    try {
        await LdapManager_ee_1.LdapManager.getInstance().service.testConnection();
    }
    catch (error) {
        const errorObject = error;
        return res.status(400).json({ message: errorObject.message });
    }
    return res.status(200).json();
});
exports.ldapController.put('/config', async (req, res) => {
    try {
        await (0, helpers_1.updateLdapConfig)(req.body);
    }
    catch (e) {
        if (e instanceof Error) {
            return res.status(400).json({ message: e.message });
        }
    }
    const data = await (0, helpers_1.getLdapConfig)();
    void typedi_1.Container.get(InternalHooks_1.InternalHooks).onUserUpdatedLdapSettings({
        user_id: req.user.id,
        ...(0, lodash_pick_1.default)(data, constants_1.NON_SENSIBLE_LDAP_CONFIG_PROPERTIES),
    });
    return res.status(200).json({ data });
});
exports.ldapController.post('/sync', async (req, res) => {
    const runType = req.body.type;
    try {
        await LdapManager_ee_1.LdapManager.getInstance().sync.run(runType);
    }
    catch (e) {
        if (e instanceof Error) {
            return res.status(400).json({ message: e.message });
        }
    }
    return res.status(200).json({});
});
exports.ldapController.get('/sync', async (req, res) => {
    const { page = '0', perPage = '20' } = req.query;
    const data = await (0, helpers_1.getLdapSynchronizations)(parseInt(page, 10), parseInt(perPage, 10));
    return res.status(200).json({ data });
});
//# sourceMappingURL=ldap.controller.ee.js.map